@@ -9,79 +9,55 @@ HTTP::MultiGet - Run many http requests at once!
   use Modern::Perl;
   use HTTP::MultiGet;
   use HTTP::Request;
-  use Test::More; # not needed, but just helps explain the way things work.
 
   my $getter=new HTTP::MultiGet;
 
-  my @requests=(map { HTTP::Request->new(GET=>'http://localhost:6503') } (1 .. 1000));
+  my @requests=(map { HTTP::Request->new(GET=>"http://localhost$_") } (1 .. 1000));
   my @responses=$getter->run_requests(@requests);
 
   my $id=0;
-  my $total=scalar(@requests);
   foreach my $response (@responses) {
-    ++$id;
-    isa_ok($response,'HTTP::Response');
-    my $code=$response->code ;
-    ok(looks_like_number($code),"Response test $id/$total should be a mumber");
-    ok(length($response->status_line) >0,"Should have some value in the status line for code: $code");
-    diag $response->status_line;
+    my $request=$requests[$id++];
+    print "Results for: ".$request->uri."\n";
+    if($response->is_success) {
+      print $response->decoded_content;
+    } else {
+      print $response->status_line,"\n";
+    }
   }
 
 
-Handling Streams of data
+=head2 Handling Multiple Large Downloads
 
   use Modern::Perl;
   use HTTP::MultiGet;
   use HTTP::Request;
 
   my $req=HTTP::Request->new(GET=>'http://some.realy.big/file/to/download.gz');
-  my $on_body=sub {
-    my ($getter,$id,$headers,$body)=@_;
+  my $req_b=HTTP::Request->new(GET=>'http://some.realy.big/file/to/download2.gz');
+
+  # create a callback 
+  my $code=sub {
+    my ($getter,$request,$headers,$chunk)=@_;
       # 0: Current HTTP::MultiGet instance
-      # 1: Id of current job
+      # 1: HTTP::Request object
       # 2: HTTP::Headers object
       # 3: Chunk of data being downloaded
-    if($headers->code==200) {
+    if($headers->header('Status')==200) {
       # do something
     } else {
       # do something with $body
     }
   };
   my $getter=new HTTP::MultiGet;
-  my ($result)=$getter->run_requests([$req,on_body=>$on_body]);
+  my ($result,$result_b)=$getter->run_requests([$req,on_body=>$code],[$req_b,on_body=>$code]);
 
-  # the on_body=>$on_body is called on each chunk downloaded
-  # $result is created when the download is completed.
-  # but $result->decoded_content is empty!
 
-If you want more control
-
-  use Modern::Perl;
-  use HTTP::MultiGet;
-
-  my $getter=new HTTP::MultiGet;
-
-  my @ids;
-  for( 1 .. 100 ) {
-    push @ids,$getter->add(HTTP::Request->new(GET=>'http://Charter.com'));
-  }
-
-  my $result=$getter->block_for_ids(@ids);
-
-  die $result unless $result;
-
-  while(my ($id,$result)=each %{$result->get_data}) {
-    if($result) {
-      my $response=$result->get_data;
-      print "Got response: $id, code was: ",$response->code,"\n";
-    } else {
-      print "Failed to get: $id error was: $result\n";
-    }
-  }
+The arguments: on_body=>$code are called called on each chunk downloaded.  $result is created when the download is completed, but $result->decoded_content is going to be empty
 
 =head1 DESCRIPTION
 
-Created as a wrapper for AnyEvent::HTTP that provides a blocking interface that most users can understand pretty well.
+Created a wrapper for: L<AnyEvent::HTTP>, but provides a more LWP like feel.
 
 =cut
 
@@ -95,17 +71,19 @@ use Data::Dumper;
 use HTTP::Response;
 use HTTP::Headers;
 use HTTP::Request;
+use Class::Method::Modifiers;
 use AnyEvent::HTTP::Request;
 use MooX::Types::MooseLike::Base qw(:all);
 use AnyEvent::HTTP::Response;
 use Carp qw(croak);
 use Ref::Util qw(is_plain_arrayref);
+require AnyEvent::HTTP;
 use namespace::clean;
 BEGIN {
 with 'Log::LogMethods';
 with 'Data::Result::Moo';
 }
-our $VERSION='1.003';
+our $VERSION='1.004';
 
 sub BUILD {
   my ($self)=@_;
@@ -236,6 +214,17 @@ has max_que_count=> (
 );
 
 
+around max_que_count=>sub {
+  my ($org,$self,$count)=@_;
+  if(looks_like_number($count)) {
+    $AnyEvent::HTTP::MAX_PER_HOST=$count if $AnyEvent::HTTP::MAX_PER_HOST < $count;
+    return $org->($self,$count);
+  } else {
+    shift;
+    return $org->(@_);
+  }
+};
+
 =head1 Class constants
 
 =over 4
@@ -282,6 +271,10 @@ sub running_count {
 
 Adds @requests to the stack, @ids relates as id=>request
 
+=item * my @ids=$self->add([$request,key=>value]);
+
+Wrapping [$request] allows passing additional key value to L<AnyEvent::HTTP::Request>, with one exception, on_body=>$code is wrapped an additional callback.
+
 =cut
 
 sub add {
@@ -496,7 +489,7 @@ sub create_request {
         my $code=sub {
 	   my ($body,$headers)=@_;
 	   my $header=new HTTP::Headers( %{$headers});
-	   $value->($self,$id,$header,$body);
+	   $value->($self,$req,$header,$body);
 	};
 	$opt->{params}->{$key}=$code;
       } else {
